import { RequestConfig } from 'umi';
import errorHandler from '@/utils/errorHandle';
import Security from '@/utils/security';
import { Base64 } from '@/utils/base64';
import { getQueryString } from '@/utils/url';

export const dva = {
  config: {
    onError(err: ErrorEvent) {
      err.preventDefault();
      console.error(err.message);
    },
  },
};

const getHeader = () => {
  let ci = getQueryString('ci') || getQueryString('c') || '4';
  // 通用参数
  const commonParams = {
    a: 11,
    av: '1.0.0',
    c: 4,
    ci: ci,
    di: '1a00bf0e978c458f7620b390714b26cc',
    lat: '',
    lng: '',
    pm: '',
    pn: 'com.starbuds.h5',
    st: 1,
    sv: '',
    t: '',
    ts: new Date().getTime(),
  };

  let toSign = '';
  Object.keys(commonParams).map((key) => {
    toSign += '&' + key + '=' + commonParams[key];
  });
  toSign = toSign.substr(1) + commonParams.pn;
  var sign = Security.encryptMd5(toSign + '.security');
  commonParams.s = sign;
  var pkg = Base64.encode(JSON.stringify(commonParams));

  return { pkg };
};

export const request: RequestConfig = {
  credentials: 'include',
  errorHandler,
  // 自定义端口规范
  errorConfig: {
    adaptor: (res) => {
      return {
        success: res.success,
        data: res.data,
        errorCode: res.code,
        errorMessage: res.msg,
      };
    },
  },
  middlewares: [],
  requestInterceptors: [
    (url, options) => {
      let headers = getHeader();
      return {
        url,
        options: { ...options, headers },
      };
    },
  ],
};
