import React from 'react';
import { request, connect, history } from 'umi';
import {
  unstable_Form as Form,
  unstable_InputItem as InputItem,
  unstable_Button as Button,
  unstable_Toast as Toast,
} from '@ant-design/mobile';
import { getQueryString } from '@/utils/url';
import styles from './index.less';
const { Group, Item } = Form;

const WingBlank: React.FC = (props) => {
  return <div style={{ padding: '0 0.24rem' }}>{props.children}</div>;
};

function Login(props: any) {
  const [form] = Form.useForm();
  const { dispatch } = props;
  const login = async (props: any) => {
    const res = await request(
      `/api-app/v1/user/getUserByUserNoOrNiceNo?params=${props.userNo}`,
    );
    if (res.success) {
      if (!res.data) {
        Toast.fail({
          content: '无效的用户ID',
        });
      } else {
        // 保存用户信息
        dispatch({
          type: 'global/saveUser',
          payload: res.data,
        });
        const backUrl = getQueryString('cb');
        if (backUrl) {
          history.replace(decodeURIComponent(backUrl));
        } else {
          history.replace('/vip');
        }
      }
    }
  };

  return (
    <div className={styles.login}>
      <Form form={form} onFinish={login}>
        <Group renderHeader="请登录您的账号">
          <Item label="ID" name="userNo" rules={[{ required: true }]}>
            <InputItem />
          </Item>
        </Group>
        <div style={{ marginTop: '12px' }}>
          <WingBlank>
            <Button type="primary" htmlType="submit" className={styles.button}>
              登录
            </Button>
          </WingBlank>
        </div>
      </Form>
    </div>
  );
}

function mapStateToProps({ global }) {
  return { ...global };
}
export default connect(mapStateToProps)(Login);
