import React, { useEffect, useState } from 'react';
import { request, history } from 'umi';
import UserCard from '@/components/UserCard';
import { unstable_Toast as Toast, unstable_Modal as Modal } from '@ant-design/mobile';
import classnames from 'classnames';
import styles from './index.less';
import { connect } from 'react-redux';

function RechargeItem(props: any) {
  const classes = [styles.rechargeItem];
  if (props.selected) {
    classes.push(styles.selected);
  }
  return (
    <div className={classnames(classes)} onClick={props.onClick}>
      <div className={styles.name}>{props.name}</div>
      <div className={styles.price}>
        <span>￥</span>
        {props.price}
      </div>
    </div>
  );
}

function PayWayItem(props: any) {
  const classes = [styles.payWayItem];
  if (props.selected) {
    classes.push(styles.selected);
  }
  return (
    <div className={classnames(classes)} onClick={props.onClick}><img src={props.icon} width={20} height={20} />&nbsp;&nbsp;{props.name}</div>
  )
}

function Recharge(props: any) {
  const [itemSelected, setItemSelected] = useState<any>(0);
  const [payWaySelected, setPayWaySelected] = useState<any>(202);
  const [rechargeItems, setRechargeItems] = useState<any>([]);
  const [wxRechargeItems, setWxRechargeItems] = useState<any>([]);

  const fetchRechargeItems = async () => {
    const res = await request('/api-app/v1/recharge/getCoinRechargeItemsGuest');
    if (res.success) {
      const list = res.data.list;
      for (let i in list) {
        if (list[i].payWay == 202) {
          setRechargeItems(list[i].items);
          setItemSelected(list[i].items[0]);
        } else if (list[i].payWay == 303) {
          setWxRechargeItems(list[i].items);
        }
      }
    }
  };

  useEffect(() => {
    // 拉取充值项目
    fetchRechargeItems();
  }, []);

  const payItem = async () => {
    const _payWay = payWaySelected
    // 判断是否登录
    if (!props.user || !props.user.userId) {
      history.push(`/login?cb=${encodeURIComponent(location.pathname)}`);
      return;
    }

    if (!itemSelected || !itemSelected.itemId) {
      Toast.warn({
        content: '请选择要充值的项目',
      });
      return;
    }

    // 创建订单
    const res = await request(
      '/api-app/v1/recharge/addCoinRechargeOrderGuest',
      {
        method: 'POST',
        requestType: 'form',
        data: {
          itemId: itemSelected.itemId,
          userId: props.user.userId,
        },
      },
    );
    if (res.success) {
      const payRes = await request('/api-app/v1/pay/addPayOrderGuest', {
        method: 'POST',
        requestType: 'form',
        data: {
          orderId: res.data.orderId,
        },
      });
      if (payRes.success) {
        if (_payWay == 202) {
          const newWindow = window.open('', '_self');
          if (newWindow != null) {
            newWindow.document.write(payRes.data.payParams);
            newWindow.focus();
          }
        } else {
          const resObj = JSON.parse(payRes.data.payParams)
          window.location.href = resObj.mwebUrl + '&redirect_url=' + encodeURIComponent(window.location.href + '/callback/wechat')
        }
      }
    }
  };

  function onPayWayChange(payWay: Number) {
    setPayWaySelected(payWay)
    if (payWay == 202) {
      setItemSelected(rechargeItems[0])
    } else {
      setItemSelected(wxRechargeItems[0])
    }
  }

  return (
    <div>
      <div
        style={{
          backgroundColor: '#FFF',
          position: 'absolute',
          left: 0,
          top: 0,
          bottom: 0,
          right: 0,
          zIndex: -1,
        }}
      ></div>
      <UserCard user={props.user} />
      <div className={styles.payWayItems}>
        <PayWayItem icon={require('../../assets/icon_alipay.png')} name='支付宝' selected={payWaySelected == 202} onClick={() => onPayWayChange(202)} />
        <PayWayItem icon={require('../../assets/icon_wechat.png')} name='微信支付' selected={payWaySelected == 303} onClick={() => onPayWayChange(303)} />
      </div>
      <div className={styles.rechargeItems}>
        {(payWaySelected == 202 ? rechargeItems : wxRechargeItems).map((item: any) => (
          <RechargeItem
            key={item.itemId}
            name={`${item.itemCoin}钻石`}
            price={item.itemPrice}
            selected={itemSelected.itemId == item.itemId}
            onClick={() => setItemSelected(item)}
          />
        ))}
      </div>
      <div style={{ width: '100%', height: '78px' }}></div>
      <div className={styles.pay}>
        <div className={styles.button} onClick={payItem}>
          支付
        </div>
      </div>
    </div>
  );
}

function mapStateToProps({ global }: any) {
  return { ...global };
}
export default connect(mapStateToProps)(Recharge);
