import React, { useState } from 'react';
import { request } from 'umi';
import UserCard from '@/components/UserCard';
import { unstable_Toast as Toast } from '@ant-design/mobile';
import classnames from 'classnames';
import styles from './index.less';
import { connect } from 'react-redux';

function VipItem(props: any) {
  const classes = [styles.vipItem];
  if (props.selected) {
    classes.push(styles.selected);
  }
  return (
    <div className={classnames(classes)} onClick={props.onClick}>
      <div className={styles.name}>{props.name}</div>
      <div className={styles.price}>
        <span>￥</span>
        {props.price}
      </div>
      <div className={styles.period}>{props.period}个月有效期</div>
    </div>
  );
}

function PrivilegeItem(props: any) {
  return (
    <div className={styles.privilegeItem}>
      <div className={styles.icon}>
        <img src={props.img} width={58} height={58} />
      </div>
      <div className={styles.name}>{props.name}</div>
    </div>
  );
}

function Vip(props: any) {
  const [vipSelected, setVipSelected] = useState<Number>(0);
  const payVip = async () => {
    // 判断是否登录
    if (!props.user || !props.user.userId) {
      Toast.fail({ content: '请先登入ID' });
      return;
    }

    // 创建订单
    const res = await request(
      '/api-app/v1/recharge/addCoinRechargeOrderGuest',
      {
        method: 'POST',
        requestType: 'form',
        data: {
          itemId: '303000010',
          userId: props.user.userId,
        },
      },
    );
    if (res.success) {
      const payRes = await request('/api-app/v1/pay/addPayOrderGuest', {
        method: 'POST',
        requestType: 'form',
        data: {
          orderId: res.data.orderId,
        },
      });
      if (payRes.success) {
        const resObj = JSON.parse(payRes.data.payParams)
        window.location.href = resObj.mwebUrl + '&redirect_url=' + encodeURIComponent(window.location.href + '/callback/wechat')
      }
    }
  };
  return (
    <div>
      <div
        style={{
          backgroundColor: '#FFF',
          position: 'absolute',
          left: 0,
          top: 0,
          bottom: 0,
          right: 0,
          zIndex: -1,
        }}
      ></div>
      <UserCard user={props.user} />
      <div className={styles.vipItems}>
        <VipItem
          name="普通会员"
          price="30"
          period="1"
          selected={vipSelected == 0}
          onClick={() => setVipSelected(0)}
        />
        <VipItem
          name="钻石会员"
          price="60"
          period="1"
          selected={vipSelected == 1}
          onClick={() => setVipSelected(1)}
        />
        <VipItem
          name="至尊会员"
          price="90"
          period="1"
          selected={vipSelected == 2}
          onClick={() => setVipSelected(2)}
        />
      </div>
      <div className={styles.privileges}>
        <div className={styles.head}></div>
        <div className={styles.items} style={{ marginTop: '30px' }}>
          <PrivilegeItem img={require('@/assets/pri_1.png')} name="专属铭牌" />
          <PrivilegeItem img={require('@/assets/pri_2.png')} name="进房金光" />
          <PrivilegeItem img={require('@/assets/pri_3.png')} name="解锁热聊" />
          <PrivilegeItem img={require('@/assets/pri_4.png')} name="主播连麦" />
        </div>
        <div style={{ marginTop: '20px' }}>
          <PrivilegeItem img={require('@/assets/pri_5.png')} name="经验加速" />
        </div>
      </div>
      <div className={styles.pay}>
        <div className={styles.button} onClick={payVip}>
          开通
        </div>
      </div>
    </div>
  );
}

function mapStateToProps({ global }) {
  return { ...global };
}
export default connect(mapStateToProps)(Vip);
